@@ -23,7 +23,7 @@ from pyranges.core.names import (
     VALID_STRAND_BEHAVIOR_TYPE,
 )
 from pyranges.core.pyranges_helpers import (
-    mypy_ensure_pyranges,
+    ensure_pyranges,
     strand_behavior_from_validated_use_strand,
     use_strand_from_validated_strand_behavior,
     validate_and_convert_strand_behavior,
@@ -93,9 +93,9 @@ def _find_chromosome_max_end_positions(grs: list["PyRanges"]) -> pd.DataFrame:
     Examples
     --------
     >>> f1, f2 = pr.example_data.f1, pr.example_data.f2  # both only have chr1
-    >>> f1["End"].max()
+    >>> int(f1["End"].max())
     9
-    >>> f2["End"].max()
+    >>> int(f2["End"].max())
     7
 
     """
@@ -220,7 +220,7 @@ def fisher_exact(tp: Series, fp: Series, fn: Series, tn: Series, pseudocount: in
     0  12   5  29   2
     1   0  12  10   2
 
-    >>> pr.stats.fisher_exact(df.TP, df.FP, df.TN, df.FN)
+    >>> pr.stats.fisher_exact(df.TP, df.FP, df.TN, df.FN) # doctest: +SKIP
        odds_ratio         P     PLeft    PRight
     0    0.165517  0.080269  0.044555  0.994525
     1    0.000000  0.000067  0.000034  1.000000
@@ -322,7 +322,7 @@ def mcc(
                 fp = 0
                 rowdicts.append({"T": lt, "F": lf, "TP": tp, "FP": fp, "TN": tn, "FN": fn, "MCC": 1})
             else:
-                for _strand in "+ -".split():
+                for _strand in ["+", "-"]:
                     tp = t[use_strand].length
                     fn = 0
                     tn = genome_length - tp
@@ -342,10 +342,10 @@ def mcc(
             continue
 
         else:  # noqa: RET507
-            j = t.join_ranges(f, strand_behavior=strand_behavior)
+            j = t.join_overlaps(f, strand_behavior=strand_behavior)
             tp_gr = j.combine_interval_columns().merge_overlaps(use_strand=use_strand)
             if use_strand:
-                for _strand in "+ -".split():
+                for _strand in ["+", "-"]:
                     tp = tp_gr[_strand].length
                     fp = f[_strand].length - tp
                     fn = t[_strand].length - tp
@@ -672,8 +672,8 @@ def simes(
         columns = list(simes.columns)
         columns.append(columns[0])
         del columns[0]
-        _simes: "PyRanges | DataFrame"
-        _simes = mypy_ensure_pyranges(simes[columns])
+        _simes: PyRanges | DataFrame
+        _simes = ensure_pyranges(simes[columns])
     else:
         _simes = sdf.groupby(by).Simes.min().reset_index()
 
@@ -726,7 +726,7 @@ def forbes(
     Examples
     --------
     >>> gr, gr2 = pr.example_data.f1, pr.example_data.f2
-    >>> pr.stats.forbes(gr, gr2, chromsizes={"chr1": 10})
+    >>> float(pr.stats.forbes(gr, gr2, chromsizes={"chr1": 10}))
     0.8333333333333334
 
     """
@@ -738,7 +738,7 @@ def forbes(
     reference_length = p.merge_overlaps(use_strand=use_strand).length
     query_length = other.merge_overlaps(use_strand=use_strand).length
 
-    intersection_sum = p.set_intersect(other, strand_behavior=strand_behavior).lengths().sum()
+    intersection_sum = p.set_intersect_overlaps(other, strand_behavior=strand_behavior).lengths().sum()
     return _chromsizes * intersection_sum / (reference_length * query_length)
 
 
@@ -778,14 +778,14 @@ def jaccard(
     --------
     >>> gr, gr2 = pr.example_data.f1, pr.example_data.f2
     >>> chromsizes = pr.example_data.chromsizes
-    >>> pr.stats.jaccard(gr, gr2)
+    >>> float(pr.stats.jaccard(gr, gr2))
     0.14285714285714285
 
     """
     strand_behavior = validate_and_convert_strand_behavior(p, other, strand_behavior)
     use_strand = use_strand_from_validated_strand_behavior(p, other, strand_behavior)
 
-    intersection_sum = p.set_intersect(other).lengths().sum()
+    intersection_sum = p.set_intersect_overlaps(other).lengths().sum()
 
     union_sum = 0
     for gr in [p, other]:
