@@ -6,9 +6,11 @@ from typing import TYPE_CHECKING
 import pandas as pd
 from natsort import natsorted  # type: ignore[import]
 
-from pyranges.core.pyranges_helpers import mypy_ensure_pyranges
+from pyranges.core.pyranges_helpers import ensure_pyranges
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping
+
     from pyranges.core.pyranges_main import PyRanges
 
 logging.basicConfig(level=logging.INFO)
@@ -51,7 +53,7 @@ def from_string(s: str) -> "PyRanges":
 
     df = pd.read_csv(StringIO(s), sep=r"\s+", index_col=None)
 
-    return mypy_ensure_pyranges(df)
+    return ensure_pyranges(df)
 
 
 def read_bed(f: Path, /, nrows: int | None = None) -> "PyRanges":
@@ -98,14 +100,25 @@ def read_bed(f: Path, /, nrows: int | None = None) -> "PyRanges":
     Contains 1 chromosomes and 2 strands.
 
     """
-    columns = (
-        "Chromosome Start End Name Score Strand ThickStart ThickEnd ItemRGB BlockCount BlockSizes BlockStarts".split()
-    )
+    columns = [
+        "Chromosome",
+        "Start",
+        "End",
+        "Name",
+        "Score",
+        "Strand",
+        "ThickStart",
+        "ThickEnd",
+        "ItemRGB",
+        "BlockCount",
+        "BlockSizes",
+        "BlockStarts",
+    ]
     path = Path(f)
     if path.name.endswith(".gz"):
         import gzip
 
-        first_start = gzip.open(path).readline().decode().split()[1]
+        first_start = gzip.open(path).readline().decode().split()[1]  # noqa: SIM115
     else:
         first_start = path.open().readline().split()[1]
 
@@ -129,7 +142,7 @@ def read_bed(f: Path, /, nrows: int | None = None) -> "PyRanges":
 
     df.columns = pd.Index(columns[: df.shape[1]])
 
-    return mypy_ensure_pyranges(df)
+    return ensure_pyranges(df)
 
 
 def read_bam(
@@ -221,24 +234,24 @@ def read_bam(
         sys.exit(1)
 
     if sparse:
-        return mypy_ensure_pyranges(bamread.read_bam(path, mapq, required_flag, filter_flag))
+        return ensure_pyranges(bamread.read_bam(path, mapq, required_flag, filter_flag))
     df = bamread.read_bam_full(path, mapq, required_flag, filter_flag)
-    return mypy_ensure_pyranges(df)
+    return ensure_pyranges(df)
 
 
 def _fetch_gene_transcript_exon_id(attribute: pd.Series, annotation: str | None = None) -> pd.DataFrame:
     no_quotes = attribute.str.replace('"', "").str.replace("'", "")
 
     df = no_quotes.str.extract(
-        "gene_id.?(.+?);(?:.*transcript_id.?(.+?);)?(?:.*exon_number.?(.+?);)?(?:.*exon_id.?(.+?);)?",
+        "gene_id.?(.+?);(?:.*group_by.?(.+?);)?(?:.*exon_number.?(.+?);)?(?:.*exon_id.?(.+?);)?",
         expand=True,
     )  # .iloc[:, [1, 2, 3]]
 
-    df.columns = pd.Index("gene_id transcript_id exon_number exon_id".split())
+    df.columns = pd.Index(["gene_id", "group_by", "exon_number", "exon_id"])
 
     if annotation == "ensembl":
         newdfs = []
-        for c in "gene_id transcript_id exon_id".split():
+        for c in ["gene_id", "group_by", "exon_id"]:
             r = df[c].astype(str).str.extract(r"(\d+)").astype(float)
             newdfs.append(r)
 
@@ -255,12 +268,11 @@ def find_first_data_line_index(file_path: Path) -> int:
     try:
         import gzip
 
-        zh = gzip.open(file_path)
-        for i, zl in enumerate(zh):
-            if zl.decode()[0] != "#":
-                first_non_comment = i
-                break
-        zh.close()
+        with gzip.open(file_path) as zh:
+            for i, zl in enumerate(zh):
+                if zl.decode()[0] != "#":
+                    first_non_comment = i
+                    break
     except (OSError, TypeError):  # not a gzipped file, or StringIO
         fh = file_path.open()
         for i, line in enumerate(fh):
@@ -320,7 +332,7 @@ def read_gtf(
     >>> from tempfile import NamedTemporaryFile
     >>> contents = ['#!genome-build GRCh38.p10']
     >>> contents.append('1\thavana\tgene\t11869\t14409\t.\t+\t.\tgene_id "ENSG00000223972"; gene_version "5"; gene_name "DDX11L1"; gene_source "havana"; gene_biotype "transcribed_unprocessed_pseudogene";')
-    >>> contents.append('1\thavana\ttranscript\t11869\t14409\t.\t+\t.\tgene_id "ENSG00000223972"; gene_version "5"; transcript_id "ENST00000456328"; transcript_version "2"; gene_name "DDX11L1"; gene_source "havana"; gene_biotype "transcribed_unprocessed_pseudogene"; transcript_name "DDX11L1-202"; transcript_source "havana"; transcript_biotype "processed_transcript"; tag "basic"; transcript_support_level "1";')
+    >>> contents.append('1\thavana\ttranscript\t11869\t14409\t.\t+\t.\tgene_id "ENSG00000223972"; gene_version "5"; group_by "ENST00000456328"; transcript_version "2"; gene_name "DDX11L1"; gene_source "havana"; gene_biotype "transcribed_unprocessed_pseudogene"; transcript_name "DDX11L1-202"; transcript_source "havana"; transcript_biotype "processed_transcript"; tag "basic"; transcript_support_level "1";')
     >>> f = NamedTemporaryFile("w")
     >>> _bytes_written = f.write("\n".join(contents))
     >>> f.flush()
@@ -388,9 +400,9 @@ def read_gtf_full(
     PyRanges
 
     """
-    dtypes = {"Chromosome": "category", "Feature": "category", "Strand": "category"}
+    dtypes: Mapping = {"Chromosome": "category", "Feature": "category", "Strand": "category"}
 
-    names = "Chromosome Source Feature Start End Score Strand Frame Attribute".split()
+    names = ["Chromosome", "Source", "Feature", "Start", "End", "Score", "Strand", "Frame", "Attribute"]
     path = Path(f)
 
     df_iter = pd.read_csv(
@@ -417,7 +429,7 @@ def read_gtf_full(
     df = pd.concat(dfs, sort=False)
     df.loc[:, "Start"] = df.Start - 1
 
-    return mypy_ensure_pyranges(df)
+    return ensure_pyranges(df)
 
 
 def parse_kv_fields(line: str) -> list[list[str]]:
@@ -440,7 +452,7 @@ def to_rows(anno: pd.Series, *, ignore_bad: bool = False) -> pd.DataFrame:
     line = ""
     try:
         for line in anno:
-            rowdicts.append(dict(parse_kv_fields(line)))  # noqa: PERF401
+            rowdicts.append(dict(parse_kv_fields(line)))
     except ValueError:
         if not ignore_bad:
             LOGGER.exception(
@@ -501,7 +513,7 @@ def read_gtf_restricted(f: str | Path, skiprows: int | None, nrows: int | None =
     attribute - A semicolon-separated list of tag-value pairs, providing additional information about each feature.
 
     """
-    dtypes = {"Chromosome": "category", "Feature": "category", "Strand": "category"}
+    dtypes: Mapping = {"Chromosome": "category", "Feature": "category", "Strand": "category"}
     path = Path(f)
 
     df_iter = pd.read_csv(
@@ -510,7 +522,7 @@ def read_gtf_restricted(f: str | Path, skiprows: int | None, nrows: int | None =
         comment="#",
         usecols=[0, 2, 3, 4, 5, 6, 8],
         header=None,
-        names="Chromosome Feature Start End Score Strand Attribute".split(),
+        names=["Chromosome", "Feature", "Start", "End", "Score", "Strand", "Attribute"],
         dtype=dtypes,
         chunksize=int(1e5),
         skiprows=skiprows if skiprows is not None else False,
@@ -520,12 +532,12 @@ def read_gtf_restricted(f: str | Path, skiprows: int | None, nrows: int | None =
     dfs = []
     for df in df_iter:
         if sum(df.Score == ".") == len(df):
-            cols_to_concat = "Chromosome Start End Strand Feature".split()
+            cols_to_concat = ["Chromosome", "Start", "End", "Strand", "Feature"]
         else:
-            cols_to_concat = "Chromosome Start End Strand Feature Score".split()
+            cols_to_concat = ["Chromosome", "Start", "End", "Strand", "Feature", "Score"]
 
         extract = _fetch_gene_transcript_exon_id(df.Attribute)
-        extract.columns = pd.Index("gene_id transcript_id exon_number exon_id".split())
+        extract.columns = pd.Index(["gene_id", "group_by", "exon_number", "exon_id"])
 
         extract.exon_number = extract.exon_number.astype(float)
 
@@ -538,7 +550,7 @@ def read_gtf_restricted(f: str | Path, skiprows: int | None, nrows: int | None =
 
     df.loc[:, "Start"] = df.Start - 1
 
-    return mypy_ensure_pyranges(df)
+    return ensure_pyranges(df)
 
 
 def to_rows_gff3(anno: pd.Series) -> pd.DataFrame:
@@ -593,9 +605,9 @@ def read_gff3(
     if not full:
         return read_gtf_restricted(path, _skiprows, nrows=nrows)
 
-    dtypes = {"Chromosome": "category", "Feature": "category", "Strand": "category"}
+    dtypes: Mapping = {"Chromosome": "category", "Feature": "category", "Strand": "category"}
 
-    names = "Chromosome Source Feature Start End Score Strand Frame Attribute".split()
+    names = ["Chromosome", "Source", "Feature", "Start", "End", "Score", "Strand", "Frame", "Attribute"]
 
     df_iter = pd.read_csv(
         path,
@@ -621,7 +633,7 @@ def read_gff3(
 
     df.loc[:, "Start"] = df.Start - 1
 
-    return mypy_ensure_pyranges(df)
+    return ensure_pyranges(df)
 
 
 def read_bigwig(f: str | Path) -> "PyRanges":
@@ -705,4 +717,4 @@ def read_bigwig(f: str | Path) -> "PyRanges":
             },
         )
 
-    return mypy_ensure_pyranges(pd.concat(dfs).reset_index(drop=True))
+    return ensure_pyranges(pd.concat(dfs).reset_index(drop=True))
