@@ -9,7 +9,7 @@ import pytest
 from hypothesis import (
     HealthCheck,
     given,
-    reproduce_failure,  # noqa: F401
+    reproduce_failure,
     settings,
 )
 
@@ -21,12 +21,12 @@ from tests.property_based.hypothesis_helper import (
     max_examples,
 )
 
-strandedness = [False, "same", "opposite"]
+strand_behavior = ["ignore", "same", "opposite"]
 no_opposite = [False, "same"]
 
 
-def run_bedtools(command, gr, gr2, strandedness, nearest_overlap=False, nearest_how=None, ties=""):
-    bedtools_strand = {False: "", "same": "-s", "opposite": "-S"}[strandedness]
+def run_bedtools(command, gr, gr2, strand_behavior, nearest_overlap=False, nearest_how=None, ties=""):
+    bedtools_strand = {False: "", "same": "-s", "opposite": "-S"}[strand_behavior]
     bedtools_overlap = {True: "", False: "-io"}[nearest_overlap]
     bedtools_how = {"upstream": "-id", "downstream": "-iu", None: ""}[nearest_how] + " -D a"
     # print("bedtools how:", bedtools_how)
@@ -35,8 +35,8 @@ def run_bedtools(command, gr, gr2, strandedness, nearest_overlap=False, nearest_
     with tempfile.TemporaryDirectory() as temp_dir:
         f1 = f"{temp_dir}/f1.bed"
         f2 = f"{temp_dir}/f2.bed"
-        gr.df.to_csv(f1, sep="\t", header=False, index=False)
-        gr2.df.to_csv(f2, sep="\t", header=False, index=False)
+        gr.to_csv(f1, sep="\t", header=False, index=False)
+        gr2.to_csv(f2, sep="\t", header=False, index=False)
 
         cmd = command.format(
             f1=f1,
@@ -46,20 +46,18 @@ def run_bedtools(command, gr, gr2, strandedness, nearest_overlap=False, nearest_
             bedtools_how=bedtools_how,
             ties=ties,
         )
-        print("cmd " * 5)
-        print(cmd)
         # ignoring the below line in bandit as only strings created by
         # the test suite is run here; no user input ever sought
         return subprocess.check_output(cmd, shell=True, executable="/bin/bash").decode()  # nosec  # nosec
 
 
-def read_bedtools_result_set_op(bedtools_result, strandedness):
-    if strandedness:
+def read_bedtools_result_set_op(bedtools_result, strand_behavior):
+    if strand_behavior:
         usecols = [0, 1, 2, 5]
-        names = "Chromosome Start End Strand".split()
+        names = ["Chromosome", "Start", "End", "Strand"]
     else:
         usecols = [0, 1, 2]
-        names = "Chromosome Start End".split()
+        names = ["Chromosome", "Start", "End"]
 
     return pd.read_csv(
         StringIO(bedtools_result),
@@ -80,9 +78,9 @@ def compare_results(bedtools_df, result) -> None:
     # dbg(result.df.dtypes)
 
     if not bedtools_df.empty:
-        assert_df_equal(result.df, bedtools_df)
+        assert_df_equal(result, bedtools_df)
     else:
-        assert bedtools_df.empty == result.df.empty
+        assert bedtools_df.empty == result.empty
 
 
 def compare_results_nearest(bedtools_df, result) -> None:
@@ -92,35 +90,35 @@ def compare_results_nearest(bedtools_df, result) -> None:
     result = result.df
 
     if len(result) != 0:
-        bedtools_df = bedtools_df.sort_values("Start End Distance".split())
-        result = result.sort_values("Start End Distance".split())
-        result_df = result["Chromosome Start End Strand Distance".split()]
+        bedtools_df = bedtools_df.sort_values(["Start", "End", "Distance"])
+        result = result.sort_values(["Start", "End", "Distance"])
+        result_df = result[["Chromosome", "Start", "End", "Strand", "Distance"]]
         assert_df_equal(result_df, bedtools_df)
     else:
         assert bedtools_df.empty
 
 
-@pytest.mark.bedtools()
-@pytest.mark.parametrize("strandedness", no_opposite)
+@pytest.mark.bedtools
+@pytest.mark.parametrize("strand_behavior", no_opposite)
 @settings(
     max_examples=max_examples,
     deadline=deadline,
     print_blob=True,
 )
 @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
-def test_set_intersect(gr, gr2, strandedness) -> None:
+def test_set_intersect(gr, gr2, strand_behavior) -> None:
     set_intersect_command = "bedtools intersect {strand} -a <(sort -k1,1 -k2,2n {f1} | bedtools merge {strand} -c 4,5,6 -o first -i -) -b <(sort -k1,1 -k2,2n {f2} | bedtools merge {strand} -c 4,5,6 -o first -i -)"
-    bedtools_result = run_bedtools(set_intersect_command, gr, gr2, strandedness)
+    bedtools_result = run_bedtools(set_intersect_command, gr, gr2, strand_behavior)
 
-    bedtools_df = read_bedtools_result_set_op(bedtools_result, strandedness)
+    bedtools_df = read_bedtools_result_set_op(bedtools_result, strand_behavior)
 
-    result = gr.set_intersect(gr2, strandedness=strandedness)
+    result = gr.set_intersect_overlaps(gr2, strand_behavior=strand_behavior)
 
     compare_results(bedtools_df, result)
 
 
-@pytest.mark.bedtools()
-@pytest.mark.parametrize("strandedness", no_opposite)
+@pytest.mark.bedtools
+@pytest.mark.parametrize("strand_behavior", no_opposite)
 @settings(
     max_examples=max_examples,
     deadline=deadline,
@@ -128,19 +126,19 @@ def test_set_intersect(gr, gr2, strandedness) -> None:
 )
 @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
 # @reproduce_failure('4.15.0', b'AXicY2RAA4zoAgAAVQAD')
-def test_set_union(gr, gr2, strandedness) -> None:
+def test_set_union(gr, gr2, strand_behavior) -> None:
     set_union_command = "cat {f1} {f2} | bedtools sort | bedtools merge {strand} -c 4,5,6 -o first -i -"  # set_union_command = "bedtools merge {strand} -c 4,5,6 -o first -i {f1}"
-    bedtools_result = run_bedtools(set_union_command, gr, gr2, strandedness)
+    bedtools_result = run_bedtools(set_union_command, gr, gr2, strand_behavior)
 
-    bedtools_df = read_bedtools_result_set_op(bedtools_result, strandedness)
+    bedtools_df = read_bedtools_result_set_op(bedtools_result, strand_behavior)
 
-    result = gr.set_union(gr2, strandedness=strandedness)
+    result = gr.set_union_overlaps(gr2, strand_behavior=strand_behavior)
 
     compare_results(bedtools_df, result)
 
 
-@pytest.mark.bedtools()
-@pytest.mark.parametrize("strandedness", strandedness)
+@pytest.mark.bedtools
+@pytest.mark.parametrize("strand_behavior", strand_behavior)
 @settings(
     max_examples=max_examples,
     deadline=deadline,
@@ -149,25 +147,26 @@ def test_set_union(gr, gr2, strandedness) -> None:
 @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
 # @reproduce_failure('4.32.2', b'AXicY2RAA4wQzIgiCAAAgAAF')
 # @reproduce_failure('5.5.4', b'AXicY2RABYyMEAqKGRgAAHMABg==')
-def test_overlap(gr, gr2, strandedness) -> None:
+@reproduce_failure("6.126.0", b"AXicY3ROKBJjYHBkhCEGRiCJzAcARwQDfg==")
+def test_overlap(gr, gr2, strand_behavior) -> None:
     overlap_command = "bedtools intersect -u {strand} -a {f1} -b {f2}"
 
-    bedtools_result = run_bedtools(overlap_command, gr, gr2, strandedness)
+    bedtools_result = run_bedtools(overlap_command, gr, gr2, strand_behavior)
 
     bedtools_df = pd.read_csv(
         StringIO(bedtools_result),
         header=None,
-        names="Chromosome Start End Name Score Strand".split(),
+        names=["Chromosome", "Start", "End", "Name", "Score", "Strand"],
         sep="\t",
     )
 
-    result = gr.overlap(gr2, strandedness=strandedness)
+    result = gr.overlap(gr2, strand_behavior=strand_behavior)
 
     compare_results(bedtools_df, result)
 
 
-@pytest.mark.bedtools()
-@pytest.mark.parametrize("strandedness", strandedness)
+@pytest.mark.bedtools
+@pytest.mark.parametrize("strand_behavior", strand_behavior)
 @settings(
     max_examples=max_examples,
     print_blob=True,
@@ -180,28 +179,21 @@ def test_overlap(gr, gr2, strandedness) -> None:
 # @reproduce_failure('4.15.0', b'AXicY2RAA4xIJAgAAABcAAQ=')
 # reproduce_failure('4.15.0', b'AXicY2RAAEYGhv9AkhHGgQIAFHQBBQ==')
 # @reproduce_failure('4.15.0', b'AXicY2QAAUYGGGCEYIQAVAgAALUACA==')
-def test_coverage(gr, gr2, strandedness) -> None:
-    print(gr.df)
-    print(gr2.df)
+def test_coverage(gr, gr2, strand_behavior) -> None:
     coverage_command = "bedtools coverage {strand} -a {f1} -b {f2}"
 
-    bedtools_result = run_bedtools(coverage_command, gr, gr2, strandedness)
+    bedtools_result = run_bedtools(coverage_command, gr, gr2, strand_behavior)
 
     bedtools_df = pd.read_csv(
         StringIO(bedtools_result),
         header=None,
         usecols=[0, 1, 2, 3, 4, 5, 6, 9],
-        names="Chromosome Start End Name Score Strand NumberOverlaps FractionOverlaps".split(),
-        dtype={"FractionOverlap": np.float_},
+        names=["Chromosome", "Start", "End", "Name", "Score", "Strand", "NumberOverlaps", "FractionOverlaps"],
+        dtype={"FractionOverlap": np.float64},
         sep="\t",
     )
 
-    result = gr.coverage(gr2, strandedness=strandedness)
-
-    print("pyranges")
-    print(result.df)
-    print("bedtools")
-    print(bedtools_df)
+    result = gr.coverage(gr2, strand_behavior=strand_behavior)
 
     # assert len(result) > 0
     assert np.all(bedtools_df.NumberOverlaps.values == result.NumberOverlaps.values)
@@ -210,18 +202,18 @@ def test_coverage(gr, gr2, strandedness) -> None:
 
 
 # @pytest.mark.bedtools
-# @pytest.mark.parametrize("strandedness", strandedness)
+# @pytest.mark.parametrize("strand_behavior", strand_behavior)
 # @settings(
 #     max_examples=max_examples,
 #     deadline=deadline,
 #     suppress_health_check=HealthCheck.all())
 # @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
 # @reproduce_failure('4.15.0', b'AXicY2RgYGAEIzgAsRkZUfkMDAAA2AAI')
-# def test_no_intersect(gr, gr2, strandedness):
+# def test_no_intersect(gr, gr2, strand_behavior):
 
 #     intersect_command = "bedtools intersect -v {strand} -a {f1} -b {f2}"
 
-#     bedtools_result = run_bedtools(intersect_command, gr, gr2, strandedness)
+#     bedtools_result = run_bedtools(intersect_command, gr, gr2, strand_behavior)
 
 #     bedtools_df = pd.read_csv(
 #         StringIO(bedtools_result),
@@ -230,19 +222,19 @@ def test_coverage(gr, gr2, strandedness) -> None:
 #         sep="\t")
 
 #     # bedtools bug: https://github.com/arq5x/bedtools2/issues/719
-#     result = gr.no_overlap(gr2, strandedness=strandedness)
+#     result = gr.no_overlap(gr2, strand_behavior=strand_behavior)
 
 #     from pydbg import dbg
 #     dbg(result)
 #     dbg(bedtools_df)
 
-#     # result2 = gr.intersect(gr2, strandedness)
+#     # result2 = gr.intersect(gr2, strand_behavior)
 
 #     compare_results(bedtools_df, result)
 
 
-@pytest.mark.bedtools()
-@pytest.mark.parametrize("strandedness", ["same", "opposite", False])  #
+@pytest.mark.bedtools
+@pytest.mark.parametrize("strand_behavior", ["same", "opposite", False])
 @settings(
     max_examples=max_examples,
     deadline=deadline,
@@ -251,25 +243,19 @@ def test_coverage(gr, gr2, strandedness) -> None:
 @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
 # @reproduce_failure('4.5.7', b'AXicLYaJCQAACIS0/YfuuQRRAbVG94Dk5LHSBgJ3ABU=')
 # @reproduce_failure('4.15.0', b'AXicY2QAAUYGGAVlIQAAAIIABQ==')
-def test_subtraction(gr, gr2, strandedness) -> None:
+def test_subtraction(gr, gr2, strand_behavior) -> None:
     subtract_command = "bedtools subtract {strand} -a {f1} -b {f2}"
 
-    bedtools_result = run_bedtools(subtract_command, gr, gr2, strandedness)
+    bedtools_result = run_bedtools(subtract_command, gr, gr2, strand_behavior)
 
     bedtools_df = pd.read_csv(
         StringIO(bedtools_result),
         header=None,
-        names="Chromosome Start End Name Score Strand".split(),
+        names=["Chromosome", "Start", "End", "Name", "Score", "Strand"],
         sep="\t",
     )
 
-    print("subtracting" * 50)
-    result = gr.range_subtract(gr2, strandedness=strandedness)
-
-    print("bedtools_result")
-    print(bedtools_df)
-    print("PyRanges result:")
-    print(result)
+    result = gr.range_subtract(gr2, strand_behavior=strand_behavior)
 
     compare_results(bedtools_df, result)
 
@@ -278,23 +264,25 @@ nearest_hows = [None, "upstream", "downstream"]
 overlaps = [True, False]
 
 
-@pytest.mark.bedtools()
-@pytest.mark.parametrize(("nearest_how", "overlap", "strandedness"), product(nearest_hows, overlaps, strandedness))
+@pytest.mark.bedtools
+@pytest.mark.parametrize(
+    ("nearest_how", "overlap", "strand_behavior"), product(nearest_hows, overlaps, strand_behavior)
+)
 @settings(
     max_examples=max_examples,
     deadline=deadline,
     print_blob=True,
 )
 @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
-def test_nearest(gr, gr2, nearest_how, overlap, strandedness) -> None:
+def test_nearest(gr, gr2, nearest_how, overlap, strand_behavior) -> None:
     nearest_command = "bedtools closest {bedtools_how} {strand} {overlap} -t first -d -a <(sort -k1,1 -k2,2n {f1}) -b <(sort -k1,1 -k2,2n {f2})"
 
-    bedtools_result = run_bedtools(nearest_command, gr, gr2, strandedness, overlap, nearest_how)
+    bedtools_result = run_bedtools(nearest_command, gr, gr2, strand_behavior, overlap, nearest_how)
 
     bedtools_df = pd.read_csv(
         StringIO(bedtools_result),
         header=None,
-        names="Chromosome Start End Strand Chromosome2 Distance".split(),
+        names=["Chromosome", "Start", "End", "Strand", "Chromosome2", "Distance"],
         usecols=[0, 1, 2, 5, 6, 12],
         sep="\t",
     )
@@ -304,18 +292,13 @@ def test_nearest(gr, gr2, nearest_how, overlap, strandedness) -> None:
     bedtools_df = bedtools_df[bedtools_df.Chromosome2 != "."]
     bedtools_df = bedtools_df.drop("Chromosome2", axis=1)
 
-    result = gr.nearest(gr2, strandedness=strandedness, overlap=overlap, how=nearest_how)
-
-    print("bedtools " * 5)
-    print(bedtools_df)
-    print("result " * 5)
-    print(result)
+    result = gr.nearest_ranges(gr2, strand_behavior=strand_behavior, overlap=overlap, how=nearest_how)
 
     compare_results_nearest(bedtools_df, result)
 
 
-@pytest.mark.bedtools()
-@pytest.mark.parametrize("strandedness", no_opposite)
+@pytest.mark.bedtools
+@pytest.mark.parametrize("strand_behavior", no_opposite)
 @settings(
     max_examples=max_examples,
     deadline=deadline,
@@ -323,7 +306,7 @@ def test_nearest(gr, gr2, nearest_how, overlap, strandedness) -> None:
     suppress_health_check=list(HealthCheck),
 )
 @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
-def test_jaccard(gr, gr2, strandedness) -> None:
+def test_jaccard(gr, gr2, strand_behavior) -> None:
     """Bedtools segfaults."""
     jaccard_command = (  # noqa: F841
         "bedtools jaccard {strand}  -a <(sort -k1,1 -k2,2n {f1}) -b <(sort -k1,1 -k2,2n {f2})"
@@ -331,33 +314,47 @@ def test_jaccard(gr, gr2, strandedness) -> None:
 
     #     # https://github.com/arq5x/bedtools2/issues/645
     #     # will make tests proper when bedtools is fixed
-    result = gr.stats.jaccard(gr2, strandedness=strandedness)
+    result = gr.stats.jaccard(gr2, strand_behavior=strand_behavior)
 
     assert 0 <= result <= 1
 
 
-@pytest.mark.bedtools()
-@pytest.mark.parametrize("strandedness", strandedness)
+@pytest.mark.bedtools
+@pytest.mark.parametrize("strand_behavior", strand_behavior)
 @settings(
     max_examples=max_examples,
     deadline=deadline,
     print_blob=True,
 )
 @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
-def test_join(gr, gr2, strandedness) -> None:
+def test_join(gr, gr2, strand_behavior) -> None:
     join_command = "bedtools intersect {strand} -wo -a {f1} -b {f2}"
 
-    bedtools_result = run_bedtools(join_command, gr, gr2, strandedness)
+    bedtools_result = run_bedtools(join_command, gr, gr2, strand_behavior)
 
     bedtools_df = pd.read_csv(
         StringIO(bedtools_result),
         header=None,
         sep="\t",
-        names="Chromosome Start End Name Score Strand Chromosome_b Start_b End_b Name_b Score_b Strand_b Overlap".split(),
+        names=[
+            "Chromosome",
+            "Start",
+            "End",
+            "Name",
+            "Score",
+            "Strand",
+            "Chromosome_b",
+            "Start_b",
+            "End_b",
+            "Name_b",
+            "Score_b",
+            "Strand_b",
+            "Overlap",
+        ],
         dtype={"Chromosome": "category", "Strand": "category"},
-    ).drop("Chromosome_b Overlap".split(), axis=1)
+    ).drop(["Chromosome_b", "Overlap"], axis=1)
 
-    result = gr.join_ranges(gr2, strandedness=strandedness)
+    result = gr.join_overlaps(gr2, strand_behavior=strand_behavior)
 
     if result.df.empty:
         assert bedtools_df.empty
@@ -365,7 +362,7 @@ def test_join(gr, gr2, strandedness) -> None:
         assert_df_equal(result.df, bedtools_df)
 
 
-@pytest.mark.bedtools()
+@pytest.mark.bedtools
 @settings(
     max_examples=max_examples,
     deadline=deadline,
@@ -378,12 +375,7 @@ def test_reldist(gr, gr2) -> None:
     bedtools_result = run_bedtools(reldist_command, gr, gr2, False)
     bedtools_result = pd.read_csv(StringIO(bedtools_result), sep="\t")
 
-    print("bedtools_result")
-    print(bedtools_result.reldist)
-
-    result = gr.stats.relative_distance(gr2)
-    print("result")
-    print(result.reldist)
+    gr.stats.relative_distance(gr2)
 
     # bug in bedtools, therefore not testing this properly
     # https://github.com/arq5x/bedtools2/issues/711
@@ -394,20 +386,20 @@ def test_reldist(gr, gr2) -> None:
 new_pos = ["union"]  # ["intersection", "union"]
 
 
-# @pytest.mark.parametrize("strandedness,new_pos", product(
-#     strandedness, new_pos))
+# @pytest.mark.parametrize("strand_behavior,new_pos", product(
+#     strand_behavior, new_pos))
 # @settings(
 #     max_examples=max_examples,
 #     deadline=deadline,
 #     print_blob=True,
 #     suppress_health_check=HealthCheck.all())
 # @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
-# def test_join_new_pos(gr, gr2, strandedness, new_pos):
+# def test_join_new_pos(gr, gr2, strand_behavior, new_pos):
 
-#     result = gr.join(gr2, strandedness=strandedness).new_position(new_pos)
+#     result = gr.join(gr2, strand_behavior=strand_behavior).new_position(new_pos)
 
 #     import numpy as np
-#     result2 = gr.join(gr2, strandedness=strandedness)
+#     result2 = gr.join(gr2, strand_behavior=strand_behavior)
 
 #     if result.df.empty:
 #         assert result2.df.empty
@@ -450,12 +442,12 @@ k_nearest_ties = ["first", "last", None]
 # k_nearest_ties = ["first", None]
 k_nearest_ties = ["last"]
 
-k_nearest_params = reversed(list(product(nearest_hows, [True, False], strandedness, k_nearest_ties)))
+k_nearest_params = reversed(list(product(nearest_hows, [True, False], strand_behavior, k_nearest_ties)))
 
 
 # @pytest.mark.bedtools
 # @pytest.mark.explore
-# @pytest.mark.parametrize("nearest_how,overlap,strandedness,ties", k_nearest_params)  #
+# @pytest.mark.parametrize("nearest_how,overlap,strand_behavior,ties", k_nearest_params)  #
 # @settings(
 #     max_examples=max_examples,
 #     deadline=deadline,
@@ -464,7 +456,7 @@ k_nearest_params = reversed(list(product(nearest_hows, [True, False], strandedne
 # )
 # @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
 # # @reproduce_failure('4.43.5', b'AXicY2RAA4zoTAAAWwAE')
-# def test_k_nearest(gr, gr2, nearest_how, overlap, strandedness, ties):
+# def test_k_nearest(gr, gr2, nearest_how, overlap, strand_behavior, ties):
 #     print("-----" * 20)
 #
 #     # gr = gr.apply(lambda df: df.astype({"Start": np.int32, "End": np.int32}))
@@ -476,7 +468,7 @@ k_nearest_params = reversed(list(product(nearest_hows, [True, False], strandedne
 #     nearest_command = "bedtools closest -k 2 {bedtools_how} {strand} {overlap} {ties} -a <(sort -k1,1 -k2,2n {f1}) -b <(sort -k1,1 -k2,2n {f2})"
 #
 #     bedtools_result = run_bedtools(
-#         nearest_command, gr, gr2, strandedness, overlap, nearest_how, ties
+#         nearest_command, gr, gr2, strand_behavior, overlap, nearest_how, ties
 #     )
 #
 #     bedtools_df = pd.read_csv(
@@ -495,7 +487,7 @@ k_nearest_params = reversed(list(product(nearest_hows, [True, False], strandedne
 #     # cannot test with k > 1 because bedtools algo has different syntax
 #     # cannot test keep_duplicates "all" or None/False properly, as the semantics is different for bedtools
 #     result = gr.k_nearest(
-#         gr2, k=2, strandedness=strandedness, overlap=overlap, how=nearest_how, ties=ties
+#         gr2, k=2, strand_behavior=strand_behavior, overlap=overlap, how=nearest_how, ties=ties
 #     )
 #
 #     # result = result.apply(lambda df: df.astype({"Start": np.int64, "End": np.int64, "Distance": np.int64}))
@@ -518,7 +510,7 @@ k_nearest_params = reversed(list(product(nearest_hows, [True, False], strandedne
 # def test_k_nearest_nearest_self_same_size(gr):
 
 #     result = gr.k_nearest(
-#         gr, k=1, strandedness=None, overlap=True, how=None, ties="first")
+#         gr, k=1, strand_behavior=None, overlap=True, how=None, ties="first")
 
 #     assert len(result) == len(gr)
 
@@ -531,11 +523,11 @@ k_nearest_params = reversed(list(product(nearest_hows, [True, False], strandedne
 # )
 # @given(gr=dfs_min(), gr2=dfs_min())  # pylint: disable=no-value-for-parameter
 # def test_k_nearest_1_vs_nearest(gr, gr2):
-#     result_k = gr.k_nearest(gr2, k=1, strandedness=None, overlap=True, how=None)
+#     result_k = gr.k_nearest(gr2, k=1, strand_behavior=None, overlap=True, how=None)
 #     if len(result_k) > 0:
 #         result_k.Distance = result_k.Distance.abs()
 #
-#     result_n = gr.nearest(gr2, strandedness=None, overlap=True, how=None)
+#     result_n = gr.nearest_ranges(gr2, strand_behavior=None, overlap=True, how=None)
 #
 #     if len(result_k) == 0 and len(result_n) == 0:
 #         pass
