@@ -34,7 +34,7 @@ method_chain = product(binary_methods, binary_methods)
 strandedness_chain = list(product(["same", "opposite"], strandedness)) + list(product(strandedness, [None]))
 
 
-@pytest.mark.bedtools()
+@pytest.mark.bedtools
 @pytest.mark.parametrize(("strandedness_chain", "method_chain"), product(strandedness_chain, method_chain))
 @settings(
     max_examples=max_examples,
@@ -47,8 +47,6 @@ strandedness_chain = list(product(["same", "opposite"], strandedness)) + list(pr
 # @reproduce_failure('5.5.4', b'AXicY2QAAUYGKGBkxM9nAAABEAAJ') # test_three_in_a_row[strandedness_chain45-method_chain45]
 # @reproduce_failure('5.5.4', b'AXicY2RAA4xIJDY+AAC2AAY=') # test_three_in_a_row[strandedness_chain24-method_chain24]
 def test_three_in_a_row(gr, gr2, gr3, strandedness_chain, method_chain) -> None:
-    print(method_chain)
-
     s1, s2 = strandedness_chain
     f1, f2 = method_chain
 
@@ -63,7 +61,6 @@ def test_three_in_a_row(gr, gr2, gr3, strandedness_chain, method_chain) -> None:
             assert (gr2.End >= 0).all()
         m2 = getattr(gr2, f2)
         gr3 = m2(gr3, strandedness=s2, suffix="_c")
-        print(gr3)
         if len(gr3) > 0:
             assert gr3.Start.dtype == np.int64
             assert (gr3.Start >= 0).all()
@@ -78,7 +75,6 @@ def test_three_in_a_row(gr, gr2, gr3, strandedness_chain, method_chain) -> None:
             assert (gr2.End >= 0).all()
         m2 = getattr(gr2, f2)
         gr3 = m2(gr3, strandedness=s2)
-        print(gr3)
         if len(gr3) > 0:
             assert gr3.Start.dtype == np.int64
             assert (gr3.Start >= 0).all()
