@@ -14,7 +14,7 @@ chr1    8    15 +
 chr1    713800    714800 -
 chr1    32    34 -"""
 
-grs = {n: pr.from_string(s) for n, s in zip(["a", "b", "c"], [a, b, c])}
+grs = {n: pr.from_string(s) for n, s in zip(["a", "b", "c"], [a, b, c], strict=False)}
 unstranded_grs = {n: gr.remove_strand() for n, gr in grs.items()}
 
 features = pr.PyRanges(
@@ -24,7 +24,6 @@ unstranded_features = features.remove_strand()
 
 
 def test_strand_vs_strand_same() -> None:
-    print(grs)
     expected_result = pr.from_string(
         """Chromosome Start End Strand a b c
 chr1  0 10  + 1 0 1
@@ -34,8 +33,6 @@ chr1 30 40  - 0 0 1""",
     )
     res = pr.count_overlaps(grs, features, strand_behavior="same")
 
-    print(res)
-
     assert_df_equal(res, expected_result)
 
 
